@@ -27,35 +27,61 @@
 #include "gnome-db.h"
 #include "gnome-db-intl.h"
 #include <libgda/libgda.h>
+#include <libgnomedb/gnome-db-util.h>
 #include <libgnomedb/gnome-db-window.h>
 
+static GtkWidget *
+create_progress_dialog (void)
+{
+	GtkWidget *dialog;
+	GtkWidget *label;
+
+	/* create dialog */
+	dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	gtk_window_set_title (GTK_WINDOW (dialog), _("Loading..."));
+	gnome_window_icon_set_from_file (GTK_WINDOW (dialog),
+					 GNOME_DB_PIXMAPDIR "/gnome-db.png");
+
+	label = gnome_db_new_label_widget (
+		_("The GNOME-DB front-end is now loading. Please wait."));
+	gtk_container_add (GTK_CONTAINER (dialog), label);
+
+	/* show dialog */
+	gtk_widget_show (dialog);
+
+	return dialog;
+}
+
 static void
 create_window (gpointer user_data)
 {
 	GtkWidget *window;
+	GtkWidget *dialog;
 
+	/* create the progress dialog */
+	dialog = create_progress_dialog ();
+
+	/* program initialization */
+	frontend_config_init ();
+	frontend_session_init ();
+
+	/* create main window */
 	window = frontend_window_new ();
-	gnome_db_window_show (GNOME_DB_WINDOW (window));
+
+	gtk_widget_destroy (dialog);
 }
 
 int
 main (int argc, char *argv[])
 {
-
-#ifdef ENABLE_NLS
 	setlocale (LC_ALL, "");
 	bindtextdomain (GETTEXT_PACKAGE, GNOMEDB_LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
-#endif
 
 	/* library initialization */
 	gnome_db_init ("gnome-db", VERSION, argc, argv);
 
-	/* program initialization */
-	frontend_config_init ();
-	frontend_session_init ();
-
 	/* run program */
 	gnome_db_main_run ((GdaInitFunc) create_window, NULL);
 
