@@ -20,20 +20,21 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "gnome-db-connection-properties.h"
-#include <libgnomedb/gnome-db-util.h>
 #include <bonobo/bonobo-i18n.h>
-#include <glade/glade.h>
+#include <gtk/gtkentry.h>
+#include <gtk/gtktable.h>
+#include <libgnomedb/gnome-db-util.h>
+#include "gnome-db-connection-properties.h"
 
 #define PARENT_TYPE GTK_TYPE_VBOX
 
 struct _GnomeDbConnectionPropertiesPrivate {
-	GladeXML *xml;
 	GdaConnection *cnc;
 
 	/* widgets */
-	GtkWidget *main_widget;
 	GtkWidget *connection_name;
+	GtkWidget *connection_string;
+	GtkWidget *connection_provider;
 	GtkWidget *connection_username;
 	GtkWidget *feature_list;
 };
@@ -49,41 +50,19 @@ static GObjectClass *parent_class = NULL;
  * Private functions
  */
 
-static gboolean
-get_widgets (GnomeDbConnectionProperties *props)
-{
-	g_return_val_if_fail (GNOME_DB_IS_CONNECTION_PROPERTIES (props), FALSE);
-
-#define GW(name) glade_xml_get_widget (props->priv->xml, name)
-
-	/* get the main widget */
-	props->priv->main_widget = GW ("connection-properties-top");
-	if (!props->priv->main_widget)
-		return FALSE;
-
-	gtk_widget_ref (props->priv->main_widget);
-	gtk_widget_unparent (props->priv->main_widget);
-
-	/* get all widgets */
-	props->priv->connection_name = GW ("connection-name");
-	props->priv->connection_username = GW ("connection-username");
-	props->priv->feature_list = GW ("connection-feature-list");
-
-	/* add loaded UI to the GnomeDbConnectionProperties widget */
-	gtk_box_pack_start (GTK_BOX (props), props->priv->main_widget, TRUE, TRUE, 0);
-
-#undef GW
-
-	return (props->priv->main_widget &&
-		props->priv->connection_name &&
-		props->priv->connection_username &&
-		props->priv->feature_list);
-}
-
 static void
 refresh_widget (GnomeDbConnectionProperties *props)
 {
 	g_return_if_fail (GNOME_DB_IS_CONNECTION_PROPERTIES (props));
+
+	gtk_entry_set_text (GTK_ENTRY (props->priv->connection_name),
+			    gda_connection_get_dsn (props->priv->cnc));
+	gtk_entry_set_text (GTK_ENTRY (props->priv->connection_string),
+			    gda_connection_get_cnc_string (props->priv->cnc));
+	gtk_entry_set_text (GTK_ENTRY (props->priv->connection_provider),
+			    gda_connection_get_provider (props->priv->cnc));
+	gtk_entry_set_text (GTK_ENTRY (props->priv->connection_username),
+			    gda_connection_get_username (props->priv->cnc));
 }
 
 /*
@@ -104,14 +83,53 @@ static void
 gnome_db_connection_properties_init (GnomeDbConnectionProperties *props,
 				     GnomeDbConnectionPropertiesClass *klass)
 {
+	GtkWidget *frame;
 	GtkWidget *table;
+	GtkWidget *label;
 
 	g_return_if_fail (GNOME_DB_IS_CONNECTION_PROPERTIES (props));
 
 	/* allocate internal structure */
 	props->priv = g_new0 (GnomeDbConnectionPropertiesPrivate, 1);
 	props->priv->cnc = NULL;
-	props->priv->xml = NULL;
+
+	/* create widgets */
+	frame = gnome_db_new_frame_widget (_("Settings"));
+	gtk_box_pack_start (GTK_BOX (props), frame, TRUE, TRUE, 2);
+
+	table = gnome_db_new_table_widget (6, 3, FALSE);
+	gtk_container_add (GTK_CONTAINER (frame), table);
+
+	label = gnome_db_new_label_widget (_("Data source name"));
+	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 2, 2);
+	props->priv->connection_name = gnome_db_new_entry_widget (0, FALSE);
+	gtk_table_attach (GTK_TABLE (table), props->priv->connection_name,
+			  1, 2, 0, 1, GTK_FILL, GTK_FILL, 2, 2);
+
+	label = gnome_db_new_label_widget (_("Connection string"));
+	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 2, 2);
+	props->priv->connection_string = gnome_db_new_entry_widget (0, FALSE);
+	gtk_table_attach (GTK_TABLE (table), props->priv->connection_string,
+			  1, 2, 1, 2, GTK_FILL, GTK_FILL, 2, 2);
+
+	label = gnome_db_new_label_widget (_("Provider"));
+	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3, GTK_FILL, GTK_FILL, 2, 2);
+	props->priv->connection_provider = gnome_db_new_entry_widget (0, FALSE);
+	gtk_table_attach (GTK_TABLE (table), props->priv->connection_provider,
+			  1, 2, 2, 3, GTK_FILL, GTK_FILL, 2, 2);
+
+	label = gnome_db_new_label_widget (_("User name"));
+	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 3, 4, GTK_FILL, GTK_FILL, 2, 2);
+	props->priv->connection_username = gnome_db_new_entry_widget (0, FALSE);
+	gtk_table_attach (GTK_TABLE (table), props->priv->connection_username,
+			  1, 2, 3, 4, GTK_FILL, GTK_FILL, 2, 2);
+
+	/* create feature list */
+	frame = gnome_db_new_frame_widget (_("Features"));
+	gtk_box_pack_start (GTK_BOX (props), frame, TRUE, TRUE, 2);
+
+	props->priv->feature_list = gnome_db_new_grid_widget (NULL);
+	gtk_container_add (GTK_CONTAINER (frame), props->priv->feature_list);
 }
 
 static void
@@ -127,11 +145,6 @@ gnome_db_connection_properties_finalize (GObject *object)
 		props->priv->cnc = NULL;
 	}
 
-	if (GLADE_IS_XML (props->priv->xml)) {
-		g_object_unref (props->priv->xml);
-		props->priv->xml = NULL;
-	}
-
 	g_free (props->priv);
 	props->priv = NULL;
 
@@ -175,23 +188,6 @@ gnome_db_connection_properties_new (GdaConnection *cnc)
 	GnomeDbConnectionProperties *props;
 
 	props = g_object_new (GNOME_DB_TYPE_CONNECTION_PROPERTIES, NULL);
-
-	/* load widgets from Glade file */
-	props->priv->xml = glade_xml_new (GNOME_DB_GLADEDIR "/connection-properties.glade",
-					  NULL, NULL);
-	if (!props->priv->xml) {
-		gda_log_error (_("Could not load the Glade XML file"));
-		g_object_unref (G_OBJECT (props));
-		return NULL;
-	}
-
-	if (!get_widgets (props)) {
-		gda_log_error (_("Could not find all widgets in Glade XML file"));
-		g_object_unref (G_OBJECT (props));
-		return NULL;
-	}
-
-	/* refresh the widget if we've got a valid connection */
 	if (GDA_IS_CONNECTION (cnc)) {
 		g_object_ref (G_OBJECT (cnc));
 		props->priv->cnc = cnc;
